﻿'//////////////////////////////////////////////////////////////////////////////////////////////////
' 
'  ACT距離計算サービス サンプルプログラム
'  CalcSettingsクラス
'
'  Copyrights (c) 2016-2023, Advanced Core Technologies, Inc. All rights reserved.
'
'  2023/09/21 Rev.1.0.0.1 KYON UseSsl変数をプロパティに変更
'  2016/02/12 Rev.1.0.0.0 MOTO 作成
'
'//////////////////////////////////////////////////////////////////////////////////////////////////

Imports Act.Dcws

''' <summary>
''' 距離計算サービスに使用する設定を指定します。
''' </summary>
Friend Class CalcSettings

    '==============================================================================================
    '  Public Constants
    '==============================================================================================
#Region "Public Constants"

    ''' <summary>
    ''' 管理サービスURLの既定値です。
    ''' </summary>
    Public Shared ReadOnly DefaultAdminUrl As String =
        "https://distcalc.act-inc.co.jp/dcadmin/admin.asmx"

    ''' <summary>
    ''' 使用する計算用道路データ（000で始まる）のNWIDの正規表現です。
    ''' </summary>
    ''' <remarks>"000"で始まるNWIDを表します。</remarks>
    Public Shared ReadOnly NWIDPattern As String = "^(000)"

    ''' <summary>
    ''' 経緯度の測地系を指定します。
    ''' </summary>
    ''' <remarks>Tokyo（日本測地系）</remarks>
    Public Shared ReadOnly Datum As Datum = Datum.Tokyo

    ''' <summary>
    ''' 経緯度の座標フォーマット識別子を指定します。
    ''' </summary>
    ''' <remarks>現在は常に0を指定します</remarks>
    Public Shared ReadOnly CoordinateFormat As Integer = 0

    ''' <summary>
    ''' 計算方法を指定します。
    ''' </summary>
    ''' <remarks>Time（時間最短）</remarks>
    Public Shared ReadOnly CalcKind As CalcKind = CalcKind.Time

    ''' <summary>
    ''' 使用交通機関を指定します。
    ''' 使用する交通機関が複数ある場合はその論理和を指定します。
    ''' </summary>
    Public Shared ReadOnly Transport As Transport = Transport.Highway

    ''' <summary>
    ''' ジオロケーション構造体の高速道路区間の出力を指定します。出力しない。
    ''' </summary>
    ''' <remarks>NotOutput（出力しない）</remarks>
    Public Shared ReadOnly HighwayOutput As HighwayOutput = HighwayOutput.NotOutput

    ''' <summary>
    ''' ジオロケーション構造体の通行料金の出力を指定します。出力しない。
    ''' </summary>
    ''' <remarks>NotOutput（出力しない）</remarks>
    Public Shared ReadOnly TollOutput As TollOutput = TollOutput.NotOutput

#End Region

    '==============================================================================================
    '  Public Property
    '==============================================================================================
#Region "Public Property"

    ''' <summary>
    ''' 通信プロトコルにSSLを使用するかどうかを指定します。
    ''' </summary>
    ''' <remarks>true（SSLを使用する）、false（SSLを使用しない）</remarks>
    Public Shared Property UseSsl As Boolean = False

#End Region

End Class
